@@ -1,3 +1,4 @@
+import json
 import os
 import ast
 import sys
@@ -8,6 +9,7 @@ import pyperclip
 import pkg_resources
 import ec2_manager
 from pprint import pformat
+from dotenv import dotenv_values
 from importlib.machinery import SourceFileLoader
 
 try:
@@ -135,8 +137,7 @@ def get_encoded_env_file(kwargs):
         return False
 
     # read the env file and encode it
-    with open(env_file_path, 'r') as env_file:
-        return ec2_manager.EC2Manager.encode_string(env_file.read())
+    return ec2_manager.EC2Manager.encode_string(json.dumps(dotenv_values(env_file_path)))
 
 
 @click.group(
